@@ -19,8 +19,8 @@ from ncdfextract import ncgettypecode
 #         print (' WARNING: format '+fmt+' could not be discovered! Assuming that it is double.')
 #         return 'd'
 
-def csv2netcdf(infile,outfile,sep=None,nalist = [''],formatlist=[],refdat = 
-        datetime(2000,1,1),tunits = 'hours',readcolnames=True, customnames=[], timestep=None):
+def csv2netcdf(infile,outfile,sep=None,nalist = [''],formatlist=[],refdat = datetime(2000,1,1), \
+        tunits = 'hours',readcolnames=True, customnames=[], timestep=None):
     '''
     purpose: convert a csv-file to a netcdf timeseries. 
 
@@ -85,7 +85,7 @@ def csv2netcdf(infile,outfile,sep=None,nalist = [''],formatlist=[],refdat =
     outfile.createVariable('time','d',('time',))
 
     # a standard timestepping. This will be overriden
-    outfile.variables['time'][:] = np.arange(lenout)
+    outfile.variables['time'][:] = arange(lenout)
 
     # if (tunits not in nalist):
     setattr(outfile.variables['time'],\
@@ -168,25 +168,25 @@ def csv2netcdf(infile,outfile,sep=None,nalist = [''],formatlist=[],refdat =
             outfile.variables['time'][iline] = \
                     (dt-refdat).total_seconds()/3600.
             if timestep == None:
-                dt = dt + dt.timedelate(hours=1)
+                dt = dt + timedelta(hours=1)
         if tunits == 'days':
             outfile.variables['time'][iline] = \
                     (dt-refdat).total_seconds()/3600./24.
             # automatic timestepping
             if timestep == None:
-                dt = dt + dt.timedelate(days=1)
+                dt = dt + timedelta(days=1)
         if tunits == 'seconds':
             outfile.variables['time'][iline] = \
                     (dt-refdat).total_seconds()
             # automatic timestepping
             if timestep == None:
-                dt = dt + dt.timedelate(seconds=1)
+                dt = dt + timedelta(seconds=1)
         if tunits == 'minutes':
             outfile.variables['time'][iline] = \
                     (dt-refdat).total_seconds()/60.
             # automatic timestepping
             if timestep == None:
-                dt = dt + dt.timedelate(minutes=1)
+                dt = dt + timedelta(minutes=1)
         if timestep != None:
             dt = dt + timestep
 
