@@ -217,9 +217,12 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
                the function is applied along the slowest changing dimensions
                (inner dimensions; dimensions in front). 
 
-    maxmembytes: The option is applicable when using appenddim. The maximum amount of bytes that is allowed for the buffers to be read/written from/to the input/output data streams. 
-    order: specify the order of the output dimensions (optional)
-    squeeze: squeeze the output variables: remove the dimensions of length unity for each of the output variables for having cleaner output
+    maxmembytes: The option is applicable when using appenddim. The maximum amount of
+                 bytes that is allowed for the buffers to be read/written from/to the
+                 input/output data streams.  order: specify the order of the output
+                 dimensions (optional) squeeze: squeeze the output variables: remove
+                 the dimensions of length unity for each of the output variables for
+                 having cleaner output
     """
 
     # track the dimensions to be selected when multiples are given
@@ -756,7 +759,8 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
         
         cont = True
         maxarefdfunc = len(refdfuncstd) 
-        while ((idnam >= maxarefdfunc) & (membytes <= maxmembytes) & cont):
+        # error: while ((idnam >= maxarefdfunc) & (membytes <= maxmembytes) & cont):
+        while ((idnam >= 0) & (membytes <= maxmembytes) & cont):
         # while loop quite extensive but does what is should-> should be reduced and simplified
             cont = False # only continue to the next loop if idnam+1 (in previous loop) was (inserted) in refdfuncstd
 
@@ -910,6 +914,8 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
     # # vsdin[ivsdin]['refdstd']: references of data stream dimensions (vsdin[..]['dnams'] to the standard dimensions (dnamsstd) 
     # dnamseldefnoiter: references
 
+    
+
     # print ('dims in:',vsdin[ivsdin]['dims'])
     # print ('dnams in:',vsdin[ivsdin]['dnams'])
     # print ('dims out:',vsdout[ivsdin]['dims'])
@@ -1004,6 +1010,9 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
     
         if adimnoapplyin[ivsdin] == []:
             adimnoapplyin[ivsdin] = [range(1)] 
+    
+    
+
 
     dimnoapplymax = []
     for iref in range(len(arefdnoiterout[ivsdout])-len(arefdfuncout[ivsdout])):
